##  Editing a Tag Group
You can edit a tag group to expand the scope of the tag group to more fact sheet types. However, to reduce the scope, you must first remove all instances of tags assigned to fact sheets of that type, including those on archived fact sheets.
Similarly, you can change the mode from single-select to multi-select. However, to switch from multi-select to single-select, you must first remove all instances of multiple tags assigned to fact sheets, including those on archived fact sheets.
An efficient way of doing this is to filter the fact sheets in the inventory and either update the data across multiple fact sheets in table view or by exporting fact sheet data as an Excel file, making the update in the spreadsheet, and importing it back. To learn more, see [Bulk Updating Data in Inventory Table View](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD "Table View lets you view and edit multiple fact sheets in a spreadsheet-like format—perfect for scanning, comparing, and updating data quickly and efficiently.") and [Bulk Updating Data Through an Excel File](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD#loioc61816d6a4da4c5fbc9bc6365f2646c2__bulk_updating_data_through_excel_file).
To edit a tag group, do the following
  1. Select the tag group that needs to be edited.
  2. Make the necessary changes.
  3. Click Save.
